Documentation
¶
Index ¶
- Constants
- func BuildFilelist(dir string, ignores []string) (files []string, err error)
- func CreateTarball(w io.Writer, filePaths []string) error
- func NewTable(out io.Writer) (t *tablewriter.Table)
- type AccountsCmd
- type AccountsCreateCmd
- type AccountsListCmd
- type AppsCmd
- type AppsCreateCmd
- type AppsInfoCmd
- type AppsListCmd
- type DeployCmd
- type LoginCmd
- type PayloadValue
- type UploadResponse
- type VersionCmd
Constants ¶
const MaxFileSize = 1073741824 // 1GB
MaxFileSize is the tarball file size allowed to be uploaded in bytes.
Variables ¶
This section is empty.
Functions ¶
func BuildFilelist ¶
BuildFilelist builds a list of files to be tarballed, with optional ignores.
func CreateTarball ¶
CreateTarball creates a tarball containing all the files in filePaths and writes it to w.
Types ¶
type AccountsCmd ¶
type AccountsCmd struct {
List AccountsListCmd `cmd help:"List accounts on Section." default:"1"`
}
AccountsCmd manages accounts on Section
type AccountsCreateCmd ¶
type AccountsCreateCmd struct{}
AccountsCreateCmd handles creating apps on Section
type AccountsListCmd ¶
type AccountsListCmd struct{}
AccountsListCmd handles listing accounts on Section
type AppsCmd ¶
type AppsCmd struct {
List AppsListCmd `cmd help:"List apps on Section." default:"1"`
Info AppsInfoCmd `cmd help:"Show detailed app information on Section."`
Create AppsCreateCmd `cmd help:"Create new app on Section."`
}
AppsCmd manages apps on Section
type AppsInfoCmd ¶
type AppsInfoCmd struct {
AccountID int `required short:"a"`
ApplicationID int `required short:"i"`
}
AppsInfoCmd shows detailed information on an app running on Section
type AppsListCmd ¶
type AppsListCmd struct {
AccountID int `required short:"a"`
}
AppsListCmd handles listing apps running on Section
type DeployCmd ¶
type DeployCmd struct {
AccountID int `default:"4322"` // harc-coded until authentication is implemented
AppID int `default:"65443"` // hard-coded for now until authentication is implmented
Debug bool
Directory string `default:"."`
ServerURL *url.URL `default:"https://aperture.section.io/new/code_upload/v1"`
ApertureURL string `default:"https://aperture.section.io/api/v1"`
EnvUpdatePathFmt string `default:"/account/%d/application/%d/environment/%s/update"`
}
DeployCmd handles deploying an app to Section.
type LoginCmd ¶
type LoginCmd struct{}
LoginCmd handles authenticating the CLI against Section's API
type PayloadValue ¶ added in v0.0.5
type PayloadValue struct {
ID string `json:"section_payload_id"`
}
PayloadValue represents the value of a trigger update payload.
type UploadResponse ¶ added in v0.0.5
type UploadResponse struct {
PayloadID string `json:"payloadID"`
}
UploadResponse represents the response from a request to the upload service.
type VersionCmd ¶
type VersionCmd struct{}
VersionCmd handles authenticating the CLI against Section's API